import React, { useRef, useEffect } from 'react';
import queryString from 'query-string';

import Icon from '../Icon';
import Typography from '../Typography';

import { Wrapper } from './styled';
import { Separator } from '../../global/otherStyled';
import data from './data';

type Props = {
  onClick: (state: string) => void;
  navbarState: string;
  children: React.ReactNode;
  displayMode: string;
};

const Navbar: React.FunctionComponent<Props> = ({
  onClick,
  navbarState,
  children,
  displayMode,
}: Props) => {
  const fileName = useRef('');

  useEffect(() => {
    const parsed = queryString.parse(window.location.search);
    fileName.current = atob(parsed.token as string);
  }, []);

  return (
    <Wrapper isHidden={displayMode === 'full'}>
      <Typography variant="title">{fileName.current}</Typography>
      {/* <Icon glyph="edit" /> */}
      <Separator />
      {
        data.btnGroup.map(ele => (
          <Icon
            key={ele.key}
            glyph={ele.content}
            isActive={navbarState === ele.content}
            onClick={(): void => { onClick(ele.content); }}
          />
        ))
      }
      {children}
    </Wrapper>
  );
};

export default Navbar;
